Index: net/quic/quic_ack_notifier.h |
diff --git a/net/quic/quic_ack_notifier.h b/net/quic/quic_ack_notifier.h |
index 160108ed41f1a409ebb80c68cf42c7dd8fd8da9a..602d86fefb8024184d4e3436ade27cd89c53ddb4 100644 |
--- a/net/quic/quic_ack_notifier.h |
+++ b/net/quic/quic_ack_notifier.h |
@@ -40,22 +40,22 @@ class NET_EXPORT_PRIVATE QuicAckNotifier { |
explicit QuicAckNotifier(DelegateInterface* delegate); |
virtual ~QuicAckNotifier(); |
- // Register a sequence number that this AckNotifier should be interested in. |
- void AddSequenceNumber(const QuicPacketSequenceNumber& sequence_number, |
- int packet_payload_size); |
- |
- // Called by the QuicConnection on receipt of new ACK frame, with the sequence |
- // number referenced by the ACK frame. |
- // Deletes the matching sequence number from the stored set of sequence |
- // numbers. If this set is now empty, call the stored delegate's |
- // OnAckNotification method. |
+ // Register a serialized packet the notifier should track. |
+ void OnSerializedPacket(); |
+ |
+ // Called on receipt of new ACK frame for an unacked packet. |
+ // Decrements the number of unacked packets and if there are none left, calls |
+ // the stored delegate's OnAckNotification method. |
// |
- // Returns true if the provided sequence_number caused the delegate to be |
- // called, false otherwise. |
- bool OnAck(QuicPacketSequenceNumber sequence_number, |
- QuicTime::Delta delta_largest_observed); |
+ // Returns true if the delegate was called, false otherwise. |
+ bool OnAck(QuicTime::Delta delta_largest_observed); |
+ |
+ // Called when we've given up waiting for a sequence number, typically when |
+ // the connection is torn down. |
+ // Returns true if there are no more unacked packets being tracked. |
+ bool OnPacketAbandoned(); |
- bool IsEmpty() { return unacked_packets_ == 0; } |
+ bool HasUnackedPackets() const { return unacked_packets_ > 0; } |
// If a packet is retransmitted by the connection, it will be sent with a |
// different sequence number. |